==> glib-web-0.4.28.tgz: package/index.js <==
import Vue from "vue";
export { Vue };

import App from "./app.vue";

import * as VueGoogleMaps from "vue2-google-maps";
Vue.use(VueGoogleMaps, {
  load: {
    key: process.env.GMAPS_API_KEY,
    libraries: "places"
  }
});

import "./styles/test.scss";
import "./styles/test.sass";

import Vuetify from "vuetify";
import "vuetify/dist/vuetify.min.css";
import "material-design-icons-iconfont/dist/material-design-icons.css";
import "@mdi/font/css/materialdesignicons.css";
Vue.use(Vuetify);

import Chartkick from "vue-chartkick";
import Chart from "chart.js";
Vue.use(Chartkick.use(Chart));

// import VueAnalytics from 'vue-analytics'
// // TODO: Avoid hardcoding
// Vue.use(VueAnalytics, {
//   id: 'UA-146876849-1'
// })

import "./extensions/string.js";
import "./extensions/array.js";

// Recursive components must be global
import VerticalPanel from "./components/panels/vertical";
import ResponsivePanel from "./components/panels/responsive";
import Component from "./components/component";
import CommonIcon from "./components/_icon";
import CommonButton from "./components/_button";
import CommonMessage from "./components/_message";
Vue.component("panels-vertical", VerticalPanel);
Vue.component("panels-responsive", ResponsivePanel);
Vue.component("common-icon", CommonIcon);
Vue.component("common-button", CommonButton);
Vue.component("common-message", CommonMessage);

// TODO: Deprecate
Vue.component("ui-component", Component);

Vue.component("glib-component", Component);

// Reuseable components
// import H1 from "./components/h1";
// import H2 from "./components/h2";
// import H3 from "./components/h3";
// import H4 from "./components/h4";
// import H5 from "./components/h5";
// import H6 from "./components/h6";
// Vue.component("views-h1", H1);
// Vue.component("views-h2", H2);
// Vue.component("views-h3", H3);
// Vue.component("views-h4", H4);
// Vue.component("views-h5", H5);
// Vue.component("views-h6", H6);

// import TurbolinksAdapter from 'vue-turbolinks'
// Vue.use(TurbolinksAdapter)

import mixin from "./components/mixins/generic.js";
Vue.mixin(mixin);

// TODO: Deprecate
import TypeUtils from "./utils/type";
Vue.use({
  install: function(Vue, options) {
    Vue.prototype.$type = {
      isObject: TypeUtils.isObject,
      isString: TypeUtils.isString,
      isNumber: TypeUtils.isNumber,
      isArray: TypeUtils.isArray,

      ifObject: TypeUtils.ifObject,
      ifString: TypeUtils.ifString,
      ifNumber: TypeUtils.ifNumber,
      ifArray: TypeUtils.ifArray
    };
  }
});

import Utils from "./utils/helper";
window.Utils = Utils;

import { settings } from "./utils/settings";
export { settings };

// TODO: https://vuejs.org/v2/guide/components-dynamic-async.html#Async-Components
// Vue.component('async-webpack-example', function (resolve) {
//   // This special require syntax will instruct Webpack to
//   // automatically split your built code into bundles which
//   // are loaded over Ajax requests.
//   require(['./my-async-component'], resolve)
// })

import VueGtag from "vue-gtag";

document.addEventListener("DOMContentLoaded", () => {
  const gtagId = settings.gtagId;
  if (gtagId) {
    Vue.use(VueGtag, {
      config: {
        id: settings.gtagId,
        params: {
          send_page_view: false
        }
      }
    });
  }

  window.vueApp = new Vue({
    el: "#app",
    vuetify: new Vuetify({
      icons: {
        iconfont: "mdi"
      },
      theme: {
        themes: Utils.settings.themes
      },
      breakpoint: {
        smAndDown: true
      }
    }),
    data: {
      page: __page,
      indicator: false,
      isStale: false
    },
    render: function(createElement) {
      return createElement(App, { props: { page: this.$data.page } });
    }
  });
});

// The above code uses Vue without the compiler, which means you cannot
// use Vue to target elements in your existing html templates. You would
// need to always use single file components.
// To be able to target elements in your existing html/erb templates,
// comment out the above code and uncomment the below
// Add <%= javascript_pack_tag 'hello_vue' %> to your layout
// Then add this markup to your html template:
//
// <div id='hello'>
//   {{message}}
//   <app></app>
// </div>

// import Vue from 'vue/dist/vue.esm'
// import App from '../app.vue'
//
// document.addEventListener('DOMContentLoaded', () => {
//   const app = new Vue({
//     el: '#hello',
//     data: {
//       message: "Can you say hello?"
//     },
//     components: { App }
//   })
// })
//
//
//
// If the using turbolinks, install 'vue-turbolinks':
//
// yarn add 'vue-turbolinks'
//
// Then uncomment the code block below:
//
// import TurbolinksAdapter from 'vue-turbolinks'
// import Vue from 'vue/dist/vue.esm'
// import App from '../app.vue'
//
// Vue.use(TurbolinksAdapter)
//
// document.addEventListener('turbolinks:load', () => {
//   const app = new Vue({
//     el: '#hello',
//     data: {
//       message: "Can you say hello?"
//     },
//     components: { App }
//   })
// })

==> glib-web-0.4.44.tgz: package/index.js <==
import Vue from "vue";
export { Vue };

import App from "./app.vue";

import * as VueGoogleMaps from "vue2-google-maps";
Vue.use(VueGoogleMaps, {
  load: {
    key: process.env.GMAPS_API_KEY,
    libraries: "places"
  }
});

import "./styles/test.scss";
import "./styles/test.sass";

import Vuetify from "vuetify";
import "vuetify/dist/vuetify.min.css";
import "material-design-icons-iconfont/dist/material-design-icons.css";
import "@mdi/font/css/materialdesignicons.css";
Vue.use(Vuetify);

import Chartkick from "vue-chartkick";
import Chart from "chart.js";
Vue.use(Chartkick.use(Chart));

// import VueAnalytics from 'vue-analytics'
// // TODO: Avoid hardcoding
// Vue.use(VueAnalytics, {
//   id: 'UA-146876849-1'
// })

import "./extensions/string.js";
import "./extensions/array.js";

// Recursive components must be global
import VerticalPanel from "./components/panels/vertical";
import ResponsivePanel from "./components/panels/responsive";
import Component from "./components/component";
import CommonIcon from "./components/_icon";
import CommonButton from "./components/_button";
import CommonMessage from "./components/_message";
Vue.component("panels-vertical", VerticalPanel);
Vue.component("panels-responsive", ResponsivePanel);
Vue.component("common-icon", CommonIcon);
Vue.component("common-button", CommonButton);
Vue.component("common-message", CommonMessage);

// TODO: Deprecate
Vue.component("ui-component", Component);

Vue.component("glib-component", Component);

// import TurbolinksAdapter from 'vue-turbolinks'
// Vue.use(TurbolinksAdapter)

import genericMixin from "./components/mixins/generic.js";
Vue.mixin(genericMixin);

import stylesMixin from "./components/mixins/styles.js";
Vue.mixin(stylesMixin);

// TODO: Deprecate
import TypeUtils from "./utils/type";
Vue.use({
  install: function(Vue, options) {
    Vue.prototype.$type = {
      isObject: TypeUtils.isObject,
      isString: TypeUtils.isString,
      isNumber: TypeUtils.isNumber,
      isArray: TypeUtils.isArray,

      ifObject: TypeUtils.ifObject,
      ifString: TypeUtils.ifString,
      ifNumber: TypeUtils.ifNumber,
      ifArray: TypeUtils.ifArray
    };
  }
});

import Utils from "./utils/helper";
window.Utils = Utils;

import { settings } from "./utils/settings";
export { settings };

// TODO: https://vuejs.org/v2/guide/components-dynamic-async.html#Async-Components
// Vue.component('async-webpack-example', function (resolve) {
//   // This special require syntax will instruct Webpack to
//   // automatically split your built code into bundles which
//   // are loaded over Ajax requests.
//   require(['./my-async-component'], resolve)
// })

import VueGtag from "vue-gtag";

document.addEventListener("DOMContentLoaded", () => {
  const gtagId = settings.gtagId;
  if (gtagId) {
    Vue.use(VueGtag, {
      config: {
        id: settings.gtagId,
        params: {
          send_page_view: false
        }
      }
    });
  }

  window.vueApp = new Vue({
    el: "#app",
    vuetify: new Vuetify({
      icons: {
        iconfont: "mdi"
      },
      theme: {
        themes: Utils.settings.themes
      },
      breakpoint: {
        smAndDown: true
      }
    }),
    data: {
      page: __page,
      indicator: false,
      isStale: false
    },
    render: function(createElement) {
      return createElement(App, { props: { page: this.$data.page } });
    }
  });
});

// The above code uses Vue without the compiler, which means you cannot
// use Vue to target elements in your existing html templates. You would
// need to always use single file components.
// To be able to target elements in your existing html/erb templates,
// comment out the above code and uncomment the below
// Add <%= javascript_pack_tag 'hello_vue' %> to your layout
// Then add this markup to your html template:
//
// <div id='hello'>
//   {{message}}
//   <app></app>
// </div>

// import Vue from 'vue/dist/vue.esm'
// import App from '../app.vue'
//
// document.addEventListener('DOMContentLoaded', () => {
//   const app = new Vue({
//     el: '#hello',
//     data: {
//       message: "Can you say hello?"
//     },
//     components: { App }
//   })
// })
//
//
//
// If the using turbolinks, install 'vue-turbolinks':
//
// yarn add 'vue-turbolinks'
//
// Then uncomment the code block below:
//
// import TurbolinksAdapter from 'vue-turbolinks'
// import Vue from 'vue/dist/vue.esm'
// import App from '../app.vue'
//
// Vue.use(TurbolinksAdapter)
//
// document.addEventListener('turbolinks:load', () => {
//   const app = new Vue({
//     el: '#hello',
//     data: {
//       message: "Can you say hello?"
//     },
//     components: { App }
//   })
// })
